@@ -34,6 +34,9 @@
 #include <net/if_var.h>
 #endif
 #if HAVE_NETINET_IN_VAR_H
+#ifdef HAVE_SYS_QUEUE_H
+#include <sys/queue.h>
+#endif
 #include <netinet/in_var.h>
 #endif
 
@@ -66,8 +69,8 @@
 typedef	void (*PFV) (void);
 typedef	int  (*PFI) (int);
 typedef	int  (*PFIV) (void);
-typedef	char* (*PFS) (int);
-typedef	oid* (*PFO) (int, int *);
+typedef	const char* (*PFS) (int);
+typedef	oid* (*PFO) (int, size_t *);
 
 extern PFV init_device[];	/* Routines for stepping through devices */
 extern PFIV next_device[];
