@@ -623,7 +623,7 @@ getmib(int groupname, int subgroupname, void *statbuf, size_t size, size_t entry
     }
     if (strbuf.len >= sizeof(struct T_error_ack)
 	&& tea->PRIM_type == T_ERROR_ACK) {
-      ret = -(tea->TLI_error == TSYSERR) ? tea->UNIX_error : EPROTO;/* Protocol error */
+      ret = -((tea->TLI_error == TSYSERR)?tea->UNIX_error:EPROTO); /* Protocol error */
       break;
     }
     if (rc != MOREDATA
@@ -758,8 +758,13 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 	ifp->ifType = 1;
 	ifp->ifSpeed = 0;
 	if (getKstat(ifrp->ifr_name, "ifspeed", &ifp->ifSpeed) == 0 && ifp->ifSpeed != 0) {
-            ifp->ifSpeed *= 1000000;
+	    /* check for SunOS patch with half implemented ifSpeed */
+            if (ifp->ifSpeed < 10000)
+		ifp->ifSpeed *= 1000000;
         }
+	else if (getKstat(ifrp->ifr_name, "ifSpeed", &ifp->ifSpeed) == 0) {
+	    /* this is good */
+	}
 	switch (ifrp->ifr_name[0]) {
 	case 'l': /* le / lo / lane (ATM LAN Emulation) */
 	    if (ifrp->ifr_name[1] == 'o') {
@@ -773,7 +778,8 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 		    ifp->ifType = 37;
 	    }
 	    break;
-	case 'h': /* hme */
+	case 'h': /* hme (SBus card) */
+	case 'e': /* eri (PCI card) */
 	case 'b': /* be */
 	    if (!ifp->ifSpeed) ifp->ifSpeed = 100000000;
 	    ifp->ifType = 6;
