@@ -1,6 +1,4 @@
 /*- This is a -*- C -*- compatible header file
- *
- * RCS $Id: kernel_sunos5.h,v 1.1.30.2 1999/06/01 07:33:48 nba Exp $
  *
  * Generic public interface for SUNOS5_INSTRUMENTATION
  *
@@ -12,6 +10,8 @@
  *
  */
 
+#include <inet/mib2.h>
+
 #define	COPY_IPADDR(fp, from, tp, to) 					\
 	fp = from;							\
 	tp = to;							\
@@ -135,11 +135,11 @@ extern "C" {
 #endif
 #endif
 
-  int 	getKstat(char *statname, char *varname, void *value);
-  int	getMibstat(mibgroup_e grid, void *resp, int entrysize,
+  int 	getKstat(const char *statname, const char *varname, void *value);
+  int	getMibstat(mibgroup_e grid, void *resp, size_t entrysize,
 		   req_e req_type, int (*comp)(void *, void *), void *arg);
   int	Get_everything(void *, void *);
-  int	getKstatInt(char *classname, char *statname, char *varname, int *value);
+  int	getKstatInt(const char *classname, const char *statname, const char *varname, int *value);
 
 #ifdef _STDC_COMPAT
 #ifdef __cplusplus
