@@ -104,6 +104,11 @@
 #include "interfaces.h"
 #include "sysORTable.h"
 
+#ifdef cygwin
+#define WIN32
+#include <windows.h>
+#endif
+
 #ifndef MIB_STATS_CACHE_TIMEOUT
 #define MIB_STATS_CACHE_TIMEOUT	5
 #endif
@@ -132,8 +137,13 @@ extern void init_routes (void);
 /* define the structure we're going to ask the agent to register our
    information at */
 struct variable4 ip_variables[] = {
+#ifdef WIN32
+    {IPFORWARDING, ASN_INTEGER, RWRITE, var_ip, 1, {1 }},
+    {IPDEFAULTTTL, ASN_INTEGER, RWRITE, var_ip, 1, {2 }},
+#else
     {IPFORWARDING, ASN_INTEGER, RONLY, var_ip, 1, {1 }},
     {IPDEFAULTTTL, ASN_INTEGER, RONLY, var_ip, 1, {2 }},
+#endif
 #ifndef sunV3
     {IPINRECEIVES, ASN_COUNTER, RONLY, var_ip, 1, {3 }},
 #endif
@@ -166,6 +176,16 @@ struct variable4 ip_variables[] = {
 #endif
     {IPADBCASTADDR, ASN_INTEGER, RONLY, var_ipAddrEntry, 3, {20, 1, 4}},
     {IPADREASMMAX, ASN_INTEGER, RONLY, var_ipAddrEntry, 3, {20, 1, 5}},
+#ifdef WIN32
+    {IPROUTEDEST, ASN_IPADDRESS, RWRITE, var_ipRouteEntry, 3, {21, 1, 1}},
+    {IPROUTEIFINDEX, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 2}},
+    {IPROUTEMETRIC1, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 3}},
+    {IPROUTEMETRIC2, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 4}},
+    {IPROUTEMETRIC3, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 5}},
+    {IPROUTEMETRIC4, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 6}},
+    {IPROUTENEXTHOP, ASN_IPADDRESS, RWRITE, var_ipRouteEntry, 3, {21, 1, 7}},
+    {IPROUTETYPE, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 8}},
+#else
     {IPROUTEDEST, ASN_IPADDRESS, RONLY, var_ipRouteEntry, 3, {21, 1, 1}},
     {IPROUTEIFINDEX, ASN_INTEGER, RONLY, var_ipRouteEntry, 3, {21, 1, 2}},
     {IPROUTEMETRIC1, ASN_INTEGER, RONLY, var_ipRouteEntry, 3, {21, 1, 3}},
@@ -174,16 +194,30 @@ struct variable4 ip_variables[] = {
     {IPROUTEMETRIC4, ASN_INTEGER, RONLY, var_ipRouteEntry, 3, {21, 1, 6}},
     {IPROUTENEXTHOP, ASN_IPADDRESS, RONLY, var_ipRouteEntry, 3, {21, 1, 7}},
     {IPROUTETYPE, ASN_INTEGER, RONLY, var_ipRouteEntry, 3, {21, 1, 8}},
+#endif
     {IPROUTEPROTO, ASN_INTEGER, RONLY, var_ipRouteEntry, 3, {21, 1, 9}},
+#ifdef WIN32
+    {IPROUTEAGE, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 10}},
+    {IPROUTEMASK, ASN_IPADDRESS, RWRITE, var_ipRouteEntry, 3, {21, 1, 11}},
+    {IPROUTEMETRIC5, ASN_INTEGER, RWRITE, var_ipRouteEntry, 3, {21, 1, 12}},
+#else
     {IPROUTEAGE, ASN_INTEGER, RONLY, var_ipRouteEntry, 3, {21, 1, 10}},
     {IPROUTEMASK, ASN_IPADDRESS, RONLY, var_ipRouteEntry, 3, {21, 1, 11}},
     {IPROUTEMETRIC5, ASN_INTEGER, RONLY, var_ipRouteEntry, 3, {21, 1, 12}},
+#endif
     {IPROUTEINFO, ASN_OBJECT_ID, RONLY, var_ipRouteEntry, 3, {21, 1, 13}},
 #ifdef USING_MIBII_AT_MODULE
+#ifdef WIN32
+    {IPMEDIAIFINDEX, ASN_INTEGER, RWRITE, var_atEntry, 3, {22, 1, 1}},
+    {IPMEDIAPHYSADDRESS, ASN_OCTET_STR, RWRITE, var_atEntry, 3, {22, 1, 2}},
+    {IPMEDIANETADDRESS, ASN_IPADDRESS, RWRITE, var_atEntry, 3, {22, 1, 3}},
+    {IPMEDIATYPE, ASN_INTEGER, RWRITE, var_atEntry, 3, {22, 1, 4}},
+#else
     {IPMEDIAIFINDEX, ASN_INTEGER, RONLY, var_atEntry, 3, {22, 1, 1}},
     {IPMEDIAPHYSADDRESS, ASN_OCTET_STR, RONLY, var_atEntry, 3, {22, 1, 2}},
     {IPMEDIANETADDRESS, ASN_IPADDRESS, RONLY, var_atEntry, 3, {22, 1, 3}},
     {IPMEDIATYPE, ASN_INTEGER, RONLY, var_atEntry, 3, {22, 1, 4}},
+#endif
 #endif
     {IPROUTEDISCARDS, ASN_COUNTER, RONLY, var_ip, 1, {23 }}
 };
@@ -244,7 +278,11 @@ void init_ip(void)
 #ifdef WIN32
 #include <iphlpapi.h>
 #define IP_STAT_STRUCTURE MIB_IPSTATS
-#endif
+WriteMethod writeIpStats;
+long ipForwarding;
+long oldipForwarding;
+long ipTTL, oldipTTL;
+#endif /* WIN32 */
 
 #if !defined(IP_STAT_STRUCTURE)
 #define IP_STAT_STRUCTURE	struct ipstat
@@ -401,10 +439,15 @@ var_ip(struct variable *vp,
 #endif
 
 #endif		/* USE_TRADITIONAL_IPSTAT */
-
 #ifdef WIN32
-       case IPFORWARDING:      return (u_char *) &ipstat.dwForwarding;
-       case IPDEFAULTTTL:      return (u_char *) &ipstat.dwDefaultTTL;
+	case IPFORWARDING:	
+    *write_method = writeIpStats;
+    ipForwarding = ipstat.dwForwarding;
+    return (u_char *) &ipstat.dwForwarding;
+	case IPDEFAULTTTL:	
+    *write_method = writeIpStats;
+    ipTTL = ipstat.dwDefaultTTL;
+    return (u_char *) &ipstat.dwDefaultTTL;
        case IPINRECEIVES:      return (u_char *) &ipstat.dwInReceives;
        case IPINHDRERRORS:     return (u_char *) &ipstat.dwInHdrErrors;
        case IPINADDRERRORS:    return (u_char *) &ipstat.dwInAddrErrors;
@@ -556,3 +599,100 @@ read_ip_stat( IP_STAT_STRUCTURE *ipstat, int magic )
     }
     return ret_value;
 }
+
+#ifdef WIN32
+int
+writeIpStats(int action,	     
+	    u_char *var_val,
+	    u_char var_val_type,
+	    size_t var_val_len,
+	    u_char *statP,
+	    oid *name,
+	    size_t name_len)
+{
+    long *buf, *oldbuf;
+    MIB_IPSTATS ipStats;
+    int var;
+    int retval = SNMP_ERR_NOERROR;
+   /* #define for ip scalar objects are 1 less than corresponding sub-id in MIB
+    * i.e. IPFORWARDING defined as 0, but ipForwarding registered as 1
+    */
+  var = name[7] - 1;
+    switch(var){
+      case IPFORWARDING:
+        buf    = &ipForwarding;
+        oldbuf = &oldipForwarding;
+        break;
+      case IPDEFAULTTTL:
+        buf    = &ipTTL;
+        oldbuf = &oldipTTL;
+        break;
+      default:
+	      return SNMP_ERR_NOTWRITABLE;
+    }
+
+    switch ( action ) {
+	case RESERVE1:		/* Check values for acceptability */
+	    if (var_val_type != ASN_INTEGER){
+                snmp_log(LOG_ERR, "not integer\n");
+		     return SNMP_ERR_WRONGTYPE;
+	    }
+	    if (var_val_len > sizeof(int)){
+                snmp_log(LOG_ERR, "bad length\n");
+		     return SNMP_ERR_WRONGLENGTH;
+	    }
+	    switch(var){
+      case IPFORWARDING:
+        if(((int)*var_val < 1) || ((int)*var_val > 2)){
+          snmp_log(LOG_ERR, "not supported ip forwarding : %d\n", *var_val);
+		      return SNMP_ERR_WRONGVALUE;
+        }
+          break;
+      case IPDEFAULTTTL:
+        if((int)*var_val < 0){
+          snmp_log(LOG_ERR, "not supported ip Default : %d\n", (int)*var_val);
+		      return SNMP_ERR_WRONGVALUE;
+        }
+      }
+	    break;
+
+	case RESERVE2:		/* Allocate memory and similar resources */
+      break;
+
+	case ACTION:		
+		/* Save the old value, in case of UNDO */
+	    
+      *oldbuf  = *buf;
+      *buf = (int)*var_val;
+	    break;
+
+	case UNDO:		/* Reverse the SET action and free resources */   
+	    *buf = *oldbuf;
+	    break;
+
+	case COMMIT:		/* Confirm the SET, performing any irreversible actions,
+					and free resources */
+    switch(var){
+      case IPFORWARDING:
+        /* Currently windows supports only ON->OFF */
+        ipStats.dwForwarding = *buf;
+        ipStats.dwDefaultTTL = MIB_USE_CURRENT_TTL;
+        if(SetIpStatistics(&ipStats) != NO_ERROR){
+          retval = SNMP_ERR_COMMITFAILED;
+          snmp_log(LOG_ERR,  "Can't set ipForwarding, supports only enable->disable \n");
+        }   
+        break;
+      case IPDEFAULTTTL:
+        if( SetIpTTL((UINT)*buf) != NO_ERROR){
+          retval = SNMP_ERR_COMMITFAILED;
+          snmp_log(LOG_ERR,  "Can't set ipDefaultTTL\n");
+        }   
+        break;
+      }
+      
+	case FREE:		/* Free any resources allocated */
+    	break;
+    }
+    return retval;
+} /* end of writeIpStats */
+#endif /* WIN32 */
