@@ -12,7 +12,9 @@
 #if HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
+#if HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 #if HAVE_SYS_PARAM_H
 #include <sys/param.h>
@@ -103,7 +105,9 @@
 #undef TCP_NODELAY
 #undef TCP_MAXSEG
 #endif
+#if HAVE_NETINET_TCP_H
 #include <netinet/tcp.h>
+#endif
 #if HAVE_NETINET_TCPIP_H
 #include <netinet/tcpip.h>
 #endif
@@ -133,6 +137,11 @@
 #include <netinet/mib_kern.h>
 #endif /* hpux */
 
+#ifdef cygwin
+#define WIN32
+#include <windows.h>
+#endif
+
 #include "tcp.h"
 #include "tcpTable.h"
 #include "sysORTable.h"
@@ -181,7 +190,11 @@ struct variable13 tcp_variables[] = {
     {TCPOUTSEGS, ASN_COUNTER, RONLY, var_tcp, 1, {11} },
     {TCPRETRANSSEGS, ASN_COUNTER, RONLY, var_tcp, 1, {12}},
 #endif
+#ifdef WIN32
+    {TCPCONNSTATE, ASN_INTEGER, RWRITE, var_tcpEntry, 3, {13, 1, 1}},
+#else
     {TCPCONNSTATE, ASN_INTEGER, RONLY, var_tcpEntry, 3, {13, 1, 1}},
+#endif
     {TCPCONNLOCALADDRESS, ASN_IPADDRESS, RONLY, var_tcpEntry, 3, {13, 1, 2}},
     {TCPCONNLOCALPORT, ASN_INTEGER, RONLY, var_tcpEntry, 3, {13, 1, 3}},
     {TCPCONNREMADDRESS, ASN_IPADDRESS, RONLY, var_tcpEntry, 3, {13, 1, 4}},
@@ -297,10 +310,21 @@ var_tcp(struct variable *vp,
 	case TCPINERRS:
 #ifdef solaris2
 				return (u_char *) &ret_value;
+#elif defined(linux)
+				if (tcpstat.tcpInErrsValid)
+				    return (u_char *) &tcpstat.tcpInErrs;
+				return NULL;
+#else
+				return NULL;
+#endif
+	case TCPOUTRSTS:
+#ifdef linux
+				if (tcpstat.tcpOutRstsValid)
+				    return (u_char *) &tcpstat.tcpOutRsts;
+				return NULL;
 #else
 				return NULL;
 #endif
-	case TCPOUTRSTS:	return NULL;
 #endif
 
 #ifdef USES_TRADITIONAL_TCPSTAT
@@ -356,7 +380,6 @@ var_tcp(struct variable *vp,
 					    - tcpstat.tcps_closed;
 				return (u_char *) &long_return;
 #endif
-
 #ifdef WIN32
        case TCPRTOALGORITHM:   return (u_char *) &tcpstat.dwRtoAlgorithm;
        case TCPRTOMIN:         return (u_char *) &tcpstat.dwRtoMin;
@@ -373,7 +396,6 @@ var_tcp(struct variable *vp,
        case TCPINERRS:   return (u_char *) &tcpstat.dwInErrs;
        case TCPOUTRSTS:  return (u_char *) &tcpstat.dwOutRsts;
 #endif
-
 	default:
 		DEBUGMSGTL(("snmpd", "unknown sub-id %d in var_tcp\n", vp->magic));
     }
