@@ -6,7 +6,9 @@
 
 #include <config.h>
 
+#if HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #if HAVE_STRING_H
 #include <string.h>
 #else
@@ -98,7 +100,9 @@
 #undef TCP_NODELAY
 #undef TCP_MAXSEG
 #endif
+#if HAVE_NETINET_TCP_H
 #include <netinet/tcp.h>
+#endif
 #if HAVE_NETINET_TCPIP_H
 #include <netinet/tcpip.h>
 #endif
@@ -127,6 +131,11 @@
 #include <netinet/mib_kern.h>
 #endif /* hpux */
 
+#ifdef cygwin
+#define WIN32
+#include <windows.h>
+#endif
+
 #include "tcp.h"
 #include "tcpTable.h"
 
@@ -150,7 +159,6 @@
 	 *  System specific implementation functions
 	 *
 	 *********************/
-
 #ifndef WIN32
 #ifndef solaris2
 
@@ -627,9 +635,11 @@ int TCP_Scan_Next(int *State,
 	return(1);	/* "OK" */
 }
 #endif /* solaris2 */
+
 #else /* WIN32 */
 #include <iphlpapi.h>
-
+WriteMethod writeTcpEntry;
+MIB_TCPROW tcp_row;
 u_char *
 var_tcpEntry(struct variable *vp,
 	     oid *name,
@@ -710,14 +720,18 @@ var_tcpEntry(struct variable *vp,
             }
         }
     }
-    if (LowState < 0) return(NULL);
+    if ((LowState < 0) || (status != NO_ERROR))
+      return(NULL);
     memcpy( (char *)name,(char *)lowest, (vp->namelen + 10) * sizeof(oid));
     *length = vp->namelen + 10;
     *write_method = 0;
     *var_len = sizeof(long);
     switch (vp->magic) {
         case TCPCONNSTATE:
+            *write_method = writeTcpEntry;
+            tcp_row = pTcpTable->table[i];
              return (u_char *) &pTcpTable->table[i].dwState;
+
         case TCPCONNLOCALADDRESS:
             return (u_char *) &pTcpTable->table[i].dwLocalAddr;
         case TCPCONNLOCALPORT:
@@ -734,4 +748,62 @@ var_tcpEntry(struct variable *vp,
     return NULL;
 }
 
-#endif
+int
+writeTcpEntry(int action,	     
+	    u_char *var_val,
+	    u_char var_val_type,
+	    size_t var_val_len,
+	    u_char *statP,
+	    oid *name,
+	    size_t name_len)
+{
+   static int oldbuf;
+   DWORD status = NO_ERROR;
+   /* Only tcpConnState is writable */
+   if((char)name[9] != 1)
+     return SNMP_ERR_NOTWRITABLE;
+
+    switch ( action ) {
+	case RESERVE1:		/* Check values for acceptability */
+	    if (var_val_type != ASN_INTEGER){
+                snmp_log(LOG_ERR, "not integer\n");
+		     return SNMP_ERR_WRONGTYPE;
+	    }
+	    if (var_val_len > sizeof(int)){
+                snmp_log(LOG_ERR, "bad length\n");
+		     return SNMP_ERR_WRONGLENGTH;
+	    }	      
+      if((int)(*var_val) != MIB_TCP_STATE_DELETE_TCB){
+        snmp_log(LOG_ERR, "not supported admin state\n");
+		    return SNMP_ERR_WRONGVALUE;
+		}
+	    break;
+
+	case RESERVE2:		/* Allocate memory and similar resources */
+		/* Using static strings, so nothing needs to be done */
+    
+	    break;
+
+	case ACTION:		
+    /* Save the old value, in case of UNDO */    
+      oldbuf   = tcp_row.dwState;
+      tcp_row.dwState = (int)*var_val;
+	    break;
+
+	case UNDO:		/* Reverse the SET action and free resources */
+   	  tcp_row.dwState = oldbuf;
+	    break;
+
+	case COMMIT:		/* Confirm the SET, performing any irreversible actions,
+					and free resources */    
+    if((status = SetTcpEntry(&tcp_row)) != NO_ERROR){
+            snmp_log(LOG_ERR,  "Error while trying to write connState %d, status = %d \n", 
+                               tcp_row.dwState, status);
+            return SNMP_ERR_COMMITFAILED;
+    }    
+	case FREE:		/* Free any resources allocated */    
+	    break;
+    }
+    return SNMP_ERR_NOERROR;
+} /* end of writeTcpEntry */
+#endif /* WIN32 */
