@@ -24,7 +24,6 @@
 #include "util_funcs.h"
 #include "keytools.h"
 #include "tools.h"
-#include "callback.h"
 #include "scapi.h"
 
 #include "usmUser.h"
@@ -54,35 +53,20 @@ oid usmUser_variables_oid[] = {1,3,6,1,6,3,15,1,2};
 
 static unsigned int usmUserSpinLock=0;
 
-int
-store_usmUser(int majorID, int minorID, void *serverarg, void *clientarg)
-{
-  /* save the user base */
-  usm_save_users("usmUser", "snmpd");
-  return SNMPERR_SUCCESS;
-}
-
-
-    
-   
-      
-  
-
 void
 init_usmUser(void)
 {
   snmpd_register_config_handler("usmUser",
-                                usm_parse_config_usmUser, NULL,
-                                "internal use only");
+                                usm_parse_config_usmUser, NULL, NULL);
   snmpd_register_config_handler("createUser",
                                 usm_parse_create_usmUser, NULL,
                                 "username (MD5|SHA) passphrase [DES] [passphrase]");
 
   /* we need to be called back later */
   snmp_register_callback(SNMP_CALLBACK_LIBRARY, SNMP_CALLBACK_STORE_DATA,
-                         store_usmUser, NULL);
+                         usm_store_users, NULL);
   
-  REGISTER_MIB("snmpv3/usmUser", usmUser_variables, variable4, \
+  REGISTER_MIB("snmpv3/usmUser", usmUser_variables, variable4,
 				 usmUser_variables_oid);
 }
 
