@@ -7,6 +7,9 @@
 #if HAVE_STRING_H
 #include <string.h>
 #endif
+#if HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
 
 #include "mibincl.h"
 #include "proxy.h"
