@@ -21,6 +21,9 @@
 #if HAVE_WINSOCK_H
 #include <winsock.h>
 #endif
+#if HAVE_STRING_H
+#include <string.h>
+#endif
 
 #include "mibincl.h"
 #include "struct.h"
@@ -93,7 +96,7 @@ u_char *var_extensible_version(struct variable *vp,
       *var_len = strlen(errmsg);
       return((u_char *) errmsg); 
     case VERDATE:
-      sprintf(errmsg,"$Date: 2000/08/14 21:52:12 $");
+      sprintf(errmsg,"$Date: 2001/04/04 13:51:18 $");
       *var_len = strlen(errmsg);
       return((u_char *) errmsg); 
     case VERCDATE:
@@ -103,7 +106,7 @@ u_char *var_extensible_version(struct variable *vp,
       *var_len = strlen(errmsg)-1;
       return((u_char *) errmsg);
     case VERIDENT:
-      sprintf(errmsg,"$Id: versioninfo.c,v 1.21 2000/08/14 21:52:12 nba Exp $");
+      sprintf(errmsg,"$Id: versioninfo.c,v 1.21.2.1 2001/04/04 13:51:18 dts12 Exp $");
       *var_len = strlen(errmsg);
       return((u_char *) errmsg);
     case VERCONFIG:
