@@ -326,7 +326,8 @@ static void update_stats(unsigned int registrationNumber, void *clientarg)
         }
       else
         {
-          snmp_log(LOG_INFO, "vmstat_solaris2 (update_stats): Kstat chain changed.");
+	  /* On some machines this floods the logfile, thus commented out */
+          /* snmp_log(LOG_INFO, "vmstat_solaris2 (update_stats): Kstat chain changed."); */
         }
     }
                  
