@@ -7,8 +7,8 @@
  */
 
 /* Prevent accidental double inclusions */
-#ifndef _MIBGROUP_VMSTAT_H
-#define _MIBGROUP_VMSTAT_H
+#ifndef _MIBGROUP_VMSTAT_SOLARIS2_H
+#define _MIBGROUP_VMSTAT_SOLARIS2_H
 
 /* The following statements are used by the configure script */
 /* Dependency requirements */
@@ -17,22 +17,6 @@ config_arch_require(solaris2, kernel_sunos5)
 /* Directive to include utility module */
 config_require(util_funcs)
 
-/* Defines for vp magic numbers */
-#define SWAPIN 3
-#define SWAPOUT 4
-#define IOSENT 5
-#define IORECEIVE 6
-#define SYSINTERRUPTS 7
-#define SYSCONTEXT 8
-#define CPUUSER 9
-#define CPUSYSTEM 10
-#define CPUIDLE 11
-#define CPUERROR 16
-#define CPURAWUSER 50
-#define CPURAWNICE 51
-#define CPURAWSYSTEM 52
-#define CPURAWIDLE 53
-
 /* MIB wants CPU_SYSTEM which is sysinfo CPU_KERNEL + CPU_WAIT */
 #define CPU_SYSTEM 4 
 
@@ -48,6 +32,6 @@ config_require(util_funcs)
 #define POLL_VALUES    5
 
 /* Declared in vmstat_solaris2.c, from prototype */
-extern void init_vmstat_solaris2(void);
+void init_vmstat_solaris2(void);
 
-#endif /* _MIBGROUP_VMSTAT_H */
+#endif /* _MIBGROUP_VMSTAT_SOLARIS2_H */
