@@ -32,8 +32,10 @@ config_arch_require(freebsd5, ucd-snmp/vmstat_freebsd2)
 config_arch_require(freebsd5, ucd-snmp/memory_freebsd2)
 config_arch_require(netbsd1, ucd-snmp/vmstat_netbsd1)
 config_arch_require(netbsd1, ucd-snmp/memory_netbsd1)
-config_arch_require(openbsd2, ucd-snmp/vmstat_freebsd2)
-config_arch_require(openbsd2, ucd-snmp/memory_freebsd2)
+config_arch_require(openbsd2, ucd-snmp/vmstat_netbsd1)
+config_arch_require(openbsd2, ucd-snmp/memory_netbsd1)
 config_arch_require(bsdi4, ucd-snmp/vmstat_bsdi4)
+config_arch_require(darwin1, ucd-snmp/vmstat_freebsd2)
+config_arch_require(darwin1, ucd-snmp/memory_freebsd2)
 config_add_mib(UCD-SNMP-MIB) 
 config_add_mib(UCD-DEMO-MIB) 
