@@ -69,6 +69,10 @@ SOFTWARE.
 #include <dmalloc.h>
 #endif
 
+#ifdef USE_LIBWRAP
+#include <tcpd.h>
+#endif
+
 #define SNMP_NEED_REQUEST_LIST
 #include "mibincl.h"
 #include "snmp_client.h"
@@ -426,6 +430,29 @@ handle_snmp_packet(int operation, struct snmp_session *session, int reqid,
 	    if ( asp->pdu->errindex > 100 )
 	        asp->pdu->errindex = 100;
     
+		    /*
+		     * If max-repetitions is 0, we shouldn't
+		     *   process the non-nonrepeaters at all
+		     *   so set up 'asp->end' accordingly
+		     */
+	    if ( asp->pdu->errindex == 0 ) {
+		if ( asp->pdu->errstat == 0 ) {
+				/* Nothing to do at all */
+		    snmp_free_varbind(asp->pdu->variables);
+		    asp->pdu->variables=NULL;
+		    asp->start=NULL;
+		}
+		else {
+		    asp->end   = asp->pdu->variables;
+		    i = asp->pdu->errstat;
+		    while ( --i > 0 ) 
+			if ( asp->end )
+			    asp->end = asp->end->next_variable;
+		    snmp_free_varbind(asp->end->next_variable);
+		    asp->end->next_variable = NULL;
+		}
+	    }
+
 	    status = handle_next_pass( asp );	/* First pass */
 	    asp->mode = RESERVE2;
 	    if ( status != SNMP_ERR_NOERROR )
