@@ -98,6 +98,9 @@ SOFTWARE.
 #if HAVE_PWD_H
 #include <pwd.h>
 #endif
+#if HAVE_GRP_H
+#include <grp.h>
+#endif
 
 #ifndef PATH_MAX
 # ifdef _POSIX_PATH_MAX
@@ -243,7 +246,7 @@ static void usage(char *prog)
 	printf("-L\t\tPrint warnings/messages to stdout/err\n");
 	printf("-s\t\tLog warnings/messages to syslog\n");
 	printf("-A\t\tAppend to the logfile rather than truncating it.\n");
-	printf("-r Don't exit if root only accessible files can't be opened\n");
+	printf("-r\t\tDon't exit if root only accessible files can't be opened\n");
 	printf("-I [-]INITLIST\tList of mib modules to initialize (or not).\n");
 	printf("\t\t (run snmpd with -Dinit_mib for a list)\n");
 	printf("-l LOGFILE\tPrint warnings/messages to LOGFILE\n");
