@@ -8,7 +8,7 @@ extern "C" {
 #endif
 
 #define MAX_CALLBACK_IDS    2
-#define MAX_CALLBACK_SUBIDS 8
+#define MAX_CALLBACK_SUBIDS 16
 
 /* Callback Major Types */
 #define SNMP_CALLBACK_LIBRARY     0
@@ -19,6 +19,7 @@ extern "C" {
 #define SNMP_CALLBACK_STORE_DATA	        1
 #define SNMP_CALLBACK_SHUTDOWN		        2
 #define SNMP_CALLBACK_POST_PREMIB_READ_CONFIG	3
+#define SNMP_CALLBACK_LOGGING			4
 
 typedef int (SNMPCallback)(int majorID, int minorID, void *serverarg,
                            void *clientarg);
@@ -34,6 +35,9 @@ void init_callbacks(void);
 int snmp_register_callback(int major, int minor, SNMPCallback *new_callback,
                            void *arg);
 int snmp_call_callbacks(int major, int minor, void *caller_arg);
+int snmp_callback_available(int major, int minor); /* is >1 available */
+int snmp_count_callbacks(int major, int minor); /* ret the number registered */
+    
 
 #ifdef __cplusplus
 }
