@@ -1,6 +1,10 @@
 #ifndef INT64_INCLUDED
 #define INT64_INCLUDED
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct counter64 U64;
 
 #define I64CHARSZ 21
@@ -13,6 +17,11 @@ void zeroU64 (U64 *);
 int isZeroU64 (U64 *);
 void printU64 (char *, U64 *);
 void printI64 (char *, U64 *);
-void read64 (U64 *, char *);
+int read64 (U64 *, const char *);
+void u64Subtract(U64 *pu64one, U64 *pu64two, U64 *pu64out);
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif
