@@ -1,5 +1,9 @@
 /* config.h:  a general config file */
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* Define IN_UCD_SNMP_SOURCE if compiling inside the ucd-snmp source tree */
 #define IN_UCD_SNMP_SOURCE 1
 
@@ -187,6 +191,7 @@
 
 /* Define if you have the vsnprintf function.  */
 #define HAVE_VSNPRINTF 1
+#define HAVE_SNPRINTF 1
 
 /* Define if you have the index function.  */
 #undef HAVE_INDEX
@@ -834,3 +839,7 @@ typedef unsigned short mode_t;
 #define USE_REVERSE_ASNENCODING       1
 #define DEFAULT_ASNENCODING_DIRECTION 1 /* 1 = reverse, 0 = forwards */
 
+#ifdef __cplusplus
+}
+#endif
+
